#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <ArduinoOTA.h>
#include "html_code.h";
#include "ir_sending.h";


const char* ssid = "Your_Wifi_SSID";
const char* password = "Your_WiFi_Password";
String btncode;

ESP8266WebServer server(80);
IPAddress local_IP(192, 168, 1, 184);//Set your Static IP Address
IPAddress gateway(192, 168, 1, 1);// Set your Gateway IP address
IPAddress subnet(255, 255, 0, 0);


void setup() {
  Serial.begin(115200);
  pinMode(LED_BUILTIN, OUTPUT);
  digitalWrite(LED_BUILTIN, LOW);

  WiFi.begin(ssid, password);
  Serial.println("Connecting to ");
  Serial.println(ssid);

  //connect to your local wi-fi network
  if (!WiFi.config(local_IP, gateway, subnet)) {
    Serial.println("STA Failed to configure");
  }
  //check wheather Nodemcu is connected to the WiFi network
  while (WiFi.status() != WL_CONNECTED) {
    delay(1000);
    Serial.print(".");
    
  }
  Serial.println("");
  Serial.println("WiFi connected..!");
  Serial.print("Got IP: ");
  Serial.println(WiFi.localIP());

  server.on("/", handle_OnConnect);
  server.on("/btnstate", handlebtn);
  server.onNotFound(handle_NotFound);

  server.begin();
  Serial.println("HTTP server started");


  ArduinoOTA.onStart([]() {
    String type;
    if (ArduinoOTA.getCommand() == U_FLASH) {
      type = "sketch";
    } else { // U_FS
      type = "filesystem";
    }

    // NOTE: if updating FS this would be the place to unmount FS using FS.end()
    Serial.println("Start updating " + type);
  });
  ArduinoOTA.onEnd([]() {
    Serial.println("\nEnd");
  });
  ArduinoOTA.onProgress([](unsigned int progress, unsigned int total) {
    Serial.printf("Progress: %u%%\r", (progress / (total / 100)));
  });
  ArduinoOTA.onError([](ota_error_t error) {
    Serial.printf("Error[%u]: ", error);
    if (error == OTA_AUTH_ERROR) {
      Serial.println("Auth Failed");
    } else if (error == OTA_BEGIN_ERROR) {
      Serial.println("Begin Failed");
    } else if (error == OTA_CONNECT_ERROR) {
      Serial.println("Connect Failed");
    } else if (error == OTA_RECEIVE_ERROR) {
      Serial.println("Receive Failed");
    } else if (error == OTA_END_ERROR) {
      Serial.println("End Failed");
    }
  });
  ArduinoOTA.begin();
  Serial.println("Ready");
  Serial.print("IP address: ");
  Serial.println(WiFi.localIP());
}

void loop() {
  server.handleClient();
    ArduinoOTA.handle();// Listen for incoming clients


}

String html = Mainpage;
void handle_OnConnect() {
  
  server.send(200, "text/html", html);
}
void handlebtn() {
  btncode = server.arg("Btnvalue");
  ir_sending(btncode);
  //Serial.println(btncode);
  server.send(200, "text/html", btncode);
}
void handle_NotFound() {
  server.send(404, "text/plain", "Not found");
}